const IS_DEV = Boolean(typeof process !== 'undefined' &&
    process.env &&
    process.env.NODE_ENV !== 'production');
const HAS_CONSOLE = typeof console !== 'undefined' &&
    typeof console.log === 'function' &&
    typeof console.warn === 'function' &&
    typeof console.error === 'function';
function log(level, message, ...args) {
    if (!IS_DEV) {
        return;
    }
    if (HAS_CONSOLE) {
        console[level](message, ...args);
    }
}
function error(message, ...args) {
    if (HAS_CONSOLE) {
        console.error(message, ...args);
    }
}
function warn(message, ...args) {
    log('warn', `Warning: ${message}`, ...args);
}
function deprecate(version, message, ...args) {
    log('warn', `Deprecation (${version}): ${message}`, ...args);
}
const logger = {
    deprecate,
    error,
    warn
};

export default logger;
export { log };
//# sourceMappingURL=index.js.map
